| Title: | Set the appropriate version of Bioconductor packages |
|---|---|
| Description: | This package provides repository information for the appropriate version of Bioconductor. |
| Authors: | Martin Morgan [aut], Marcel Ramos [ctb], Bioconductor Package Maintainer [ctb, cre] |
| Maintainer: | Bioconductor Package Maintainer <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 3.24.0 |
| Built: | 2026-05-29 08:33:31 UTC |
| Source: | https://github.com/bioc/BiocVersion |
The 'major' and 'minor' version of this package determines the version
of Bioconductor software packages to be installed by the
install function.
packageVersion("BiocVersion")[,1:2]packageVersion("BiocVersion")[,1:2]